Module: ActionDispatch
- Defined in:
- lib/galakei/use_rack_request_to_extract_sid.rb
Overview
Patch the abstract session store to accomplish the following things:
-
avoid issue rails.lighthouseapp.com/projects/8994/tickets/6108-activerecord-session-store-clobbers-params#ticket-6108-2 by using Rack::Request instead of ActionDispatch::Request
-
session ID in the params overwrites session ID in the cookie
-
make sure we always set the session ID in SSL in case the handset uses different cookies for HTTP/HTTPS
Defined Under Namespace
Modules: Session